@@ -13,7 +13,7 @@ sub new {
 
 sub init {
   my $self = shift;
-  @{$self}{ qw(Declarator Offset) } = @_;
+  @{$self}{ qw(Declarator Offset WarningOnRedefined) } = @_;
   return $self;
 }
 
@@ -32,6 +32,11 @@ sub declarator {
   return $self->{Declarator}
 }
 
+sub warning_on_redefine {
+  my $self = shift;
+  return $self->{WarningOnRedefined}
+}
+
 sub skip_declarator {
   my $self = shift;
   my $decl = $self->declarator;
